@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-09-07 17:01:51
+@LastEditTime: 2021-09-07 17:25:57
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -726,7 +726,7 @@ class GetPropGiveHandler(SevenBaseHandler):
 
         except Exception as ex:
             db_transaction.rollback_transaction()
-            self.logging_link_error("GetPropGiveHandler:" + str(ex))
+            self.logging_link_error("GetPropGiveHandler:" + str(ex) + ":" + str(update_sql))
             return self.reponse_json_error("Error", "系统繁忙,请稍后再试")
         return self.reponse_json_success({"prop_type": prop_give.prop_type, "num": 1})
 
